﻿using System;
using System.Windows.Forms;

namespace HtmlContents
{
   public partial class Form1 : Form
   {
      public Form1()
      {
         InitializeComponent();
      }

      private void Form1_Load(object sender, EventArgs e)
      {
         lblResult.Text = ContentsGenerator.GenerateTemplate(tbTag.Text, tbClass.Text);
         string[] arguments = Environment.GetCommandLineArgs();
         if (arguments.Length > 1)
         {
            cbAutoGenerate.Checked = false;
            tbFile.Text = arguments[1];
         }
      }


      private void cmdSearch_Click(object sender, EventArgs e)
      {
         if (openHtmlFileDialog.ShowDialog() == DialogResult.OK)
         {
            //Get the path of specified file
            String file = openHtmlFileDialog.FileName;

            if (!file.ToUpper().EndsWith("HTM") & !file.ToUpper().EndsWith("HTML"))
            {
               Console.Beep();
               return;
            }

            tbFile.Text = file;
            if (cbAutoGenerate.Checked)
            {
               try
               {
                  Cursor = Cursors.WaitCursor;
                  tbResult.Text = ContentsGenerator.GenerateContents(file, tbTag.Text, tbClass.Text);
               }
               finally 
               {
                  Cursor = Cursors.Default;
               }

               if (cbClipboard.Checked)
               {
                  Clipboard.SetText(tbResult.Text);
                  MessageBox.Show("Inhaltverzeichnis in der Zwischenablage");
               }
            }
         }
      }

      private void Form1_DragEnter(object sender, DragEventArgs e)
      {
         if (e.Data.GetDataPresent(DataFormats.FileDrop)) e.Effect = DragDropEffects.Copy;
      }

      private void Form1_DragDrop(object sender, DragEventArgs e)
      {
         string[] files = (string[])e.Data.GetData(DataFormats.FileDrop);
         if (files.Length == 0)
            return;
         var file = files[0];
         if (!file.ToUpper().EndsWith("HTM") & !file.ToUpper().EndsWith("HTML"))
         {
            Console.Beep();
            return;
         }

         tbFile.Text = file;
         if (cbAutoGenerate.Checked)
         {
            try
            {
               Cursor = Cursors.WaitCursor;
               tbResult.Text = ContentsGenerator.GenerateContents(file, tbTag.Text, tbClass.Text);
            }
            finally
            {
               Cursor = Cursors.Default;
            }

            if (cbClipboard.Checked)
            {
               Clipboard.SetText(tbResult.Text);
               MessageBox.Show("Inhaltverzeichnis in der Zwischenablage");
            }
         }
      }

      private void cbAutoGenerate_CheckedChanged(object sender, EventArgs e)
      {
         cmdGenerate.Enabled = !cbAutoGenerate.Checked;
      }

      private void tbTag_TextChanged(object sender, EventArgs e)
      {
         lblResult.Text = ContentsGenerator.GenerateTemplate(tbTag.Text, tbClass.Text);
      }

      private void tbClass_TextChanged(object sender, EventArgs e)
      {
         lblResult.Text = ContentsGenerator.GenerateTemplate(tbTag.Text, tbClass.Text);
      }

      private void cmdGenerate_Click(object sender, EventArgs e)
      {
         if (!tbFile.Text.ToUpper().EndsWith("HTM") & !tbFile.Text.ToUpper().EndsWith("HTML"))
         {
            MessageBox.Show("keine HTML-Datei angegeben");
            return;
         }
         try
         {
            Cursor = Cursors.WaitCursor;
            tbResult.Text = ContentsGenerator.GenerateContents(tbFile.Text, tbTag.Text, tbClass.Text);
         }
         finally
         {
            Cursor = Cursors.Default;
         }

         if (cbClipboard.Checked)
         {
            Clipboard.SetText(tbResult.Text);
            MessageBox.Show("Inhaltverzeichnis in der Zwischenablage");
         }
      }

      private void button1_Click(object sender, EventArgs e)
      {
         AboutBox a = new AboutBox();
         a.ShowDialog();
      }
   }
}

